<?php
// Register Custom Post Type
function register_mycustomposttype() {
    $args = array(
        'labels' => array(
            'name' => _x( 'Puntos de Venta', 'Post Type General Name', 'text_domain' ),
            'singular_name' => _x( 'Punto de Venta', 'Post Type General Name', 'text_domain' ),
            'add_new' => __( 'Añadir Nuevo', 'text_domain' ),
            'add_new_item' => __( 'Nuevo punto de venta', 'text_domain' ),
        ),
        'description'           => __( 'Listado de puntos de venta', 'text_domain' ),
        'supports'              => array( 'title', 'editor', 'thumbnail', 'custom-fields' ),
        'hierarchical'          => false,
        'public'                => true,
        'show_ui'               => true,
        'show_in_menu'          => true,
        'menu_position'         => 27,
        'menu_icon'             => 'dashicons-networking',
        'show_in_admin_bar'     => true,
        'show_in_nav_menus'     => true,
        'can_export'            => true,
        'has_archive'           => true,        
        'exclude_from_search'   => false,
        'publicly_queryable'    => true,
        'capability_type'       => 'page',
    );
    register_post_type( 'punto-de-venta', $args );

}
add_action( 'init', 'register_mycustomposttype', 0 );


// Custom Columns in back end list
function pos_list_columns( $columns ) {
    $columns = array(
        'cb' => '<input type="checkbox" />',
        'title' => 'Título',
        'data' => 'Información Contacto',
        'date' => 'Fecha',
    );

    return $columns;
}
add_filter( 'manage_punto-de-venta_posts_columns', 'pos_list_columns' ) ;


// Content of Custom Columns in back end list
function pos_list_columns_content($column, $post_id) {
    global $post;

    $return = "";
    if ($column == 'data') {
        $pos_contact = get_post_meta( $post_id, 'pos_contact', true );
        $pos_phone = get_post_meta( $post_id, 'pos_phone', true );
        $pos_email = get_post_meta( $post_id, 'pos_email', true );
        $return = "<strong>" . $pos_contact . "</strong><br>";
        $return .= $pos_phone;
        if (!empty($pos_email)) { $return .= ' - <a href="mailto:' . $pos_email . '" target="_blank">' . $pos_email . '</a>';}
    }
    echo $return;
}
add_action('manage_punto-de-venta_posts_custom_column', 'pos_list_columns_content', 10, 2);



function my_distributors_shortcode( $atts ) {
    ob_start();

    $args = array(
        'post_type' => 'punto-de-venta',
        'orderby' => 'title',
        'order' => 'ASC',
        'posts_per_page' => '-1',
    );

    if (!empty($_POST["pos_search"])) {
        $args["s"] = sanitize_text_field($_POST["pos_search"]);
    }
    $query = new WP_Query( $args );

    $pos = array();
    while ($query->have_posts()): $query->the_post();
        $pos_title = get_the_title();
        $pos_description = apply_filters('the_content', get_the_content());
        $pos_phone = get_post_meta( get_the_ID(), 'pos_phone', true );
        $pos_email = get_post_meta( get_the_ID(), 'pos_email', true );
        $pos_url = get_post_meta( get_the_ID(), 'pos_url', true );
        $pos_map = get_post_meta( get_the_ID(), 'pos_map', true );
        $pos_link = get_permalink();

        $pos[] = array($pos_title, $pos_description, $pos_phone, $pos_email, $pos_url, $pos_map, $pos_link);
    endwhile;
    wp_reset_query();?>

    <div id="map" style="width: 100%; height: 480px; margin: 15px auto;"></div>

    <form id="formpos" name="formpos" method="post">
        <input type="text" id="pos_search" name="pos_search">
        <input type="submit" id="pos_submit" name="pos_submit" value="Buscar">
    </form>

    <?php
    $distributors = '';
    $i = 0;

    foreach ($pos as $key => $value) {
        if ($i == 0) {
            $distributors .= '[et_pb_row admin_label="Fila" make_fullwidth="on"]';
        }

        $distributors .= '[et_pb_column type="1_4"]';

        $distributors .= '<h2>' . $value["0"] . '</h2>';
        $distributors .= '<p>' . $value["5"]["address"] . "<br>";
        $distributors .= '<a href="tel:' . $value["2"] . '" target="_blank">' . $value["2"] . '</a><br>';
        $distributors .= '<a href="mailto:' . $value["3"] . '" target="_blank">' . $value["3"] . '</a><br>';
        $distributors .= '<a href="' . $value["4"] . '" target="_blank">' . $value["4"] . '</a><br>';
        $distributors .= '<a href="' . $value["6"] . '">Más información</a></p>';

        $distributors .= '[/et_pb_column]';

        $i++;

        if (($i >= 4) || (end(array_keys($pos)) == $key)) {
            $i = 0;
            $distributors .= '[/et_pb_row]';
        }  
    }

    echo do_shortcode($distributors);?>

    <script type="text/javascript">
    function initMap() {
        var map = new google.maps.Map(document.getElementById('map'), {
            center: {lat: 40.4167754, lng: -3.7037901999999576}, //Centro Madrid
            zoom: 6
        });

        // Create a marker and set its position.
        <?php foreach ($pos as $key => $value) {?>
        var marker_<?php echo $key;?> = new google.maps.Marker({
            map: map,
            position: {lat: <?php echo $value["5"]["lat"];?>, lng: <?php echo $value["5"]["lng"];?>},
            title: "<?php echo $value['5']['address'];?>",
            icon: "<?php echo get_stylesheet_directory_uri();?>/images/marker.png"
        });

        var pos_content = '<?php echo $value["0"];?><br>';
        pos_content += '<a href="tel:<?php echo $value["2"];?>" target="_blank"><?php echo $value["2"];?></a><br>';
        pos_content += '<a href="mailto:<?php echo $value["3"];?>" target="_blank"><?php echo $value["3"];?></a><br>';
        pos_content += '<a href="<?php echo $value["4"];?>" target="_blank"><?php echo $value["4"];?></a><br>';

        var infowindow_<?php echo $key;?> = new google.maps.InfoWindow({
            content: pos_content
        });

        marker_<?php echo $key;?>.addListener('click', function() {
            infowindow_<?php echo $key;?>.open(map, marker_<?php echo $key;?>);
        });
        <?php }?>
    }
    </script>

    <script async defer src="https://maps.googleapis.com/maps/api/js?key=AIzaSyCEVKZn-YL6Qeulwqvc6JUK9m6r6YfzyKI&callback=initMap"></script>

    <?php
    return ob_get_clean();
}
add_shortcode( 'distributors', 'my_distributors_shortcode' );